==> haskell-hakyll-4.9.2.0-7-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hakyll.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hakyll
version: 4.9.2.0
id: hakyll-4.9.2.0-KCb9Tlj9EDQ1Ndzd854zVD
key: hakyll-4.9.2.0-KCb9Tlj9EDQ1Ndzd854zVD
license: BSD3
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
homepage: http://jaspervdj.be/hakyll
synopsis: A static website compiler library
description:
    Hakyll is a static website compiler library. It provides you with the tools to
    create a simple or advanced static website using a Haskell DSL and formats
    such as markdown or RST. You can find more information, including a tutorial,
    on the website:
    .
    * <http://jaspervdj.be/hakyll>
    .
    If you seek assistance, there'\''s:
    .
    * A google group: <http://groups.google.com/group/hakyll>
    .
    * An IRC channel, @#hakyll@ on freenode
    .
    Additionally, there'\''s the Haddock documentation in the different modules,
    meant as a reference.
category: Web
author: Jasper Van der Jeugt <m@jaspervdj.be>
exposed: True
exposed-modules:
    Hakyll Hakyll.Core.Compiler Hakyll.Core.Configuration
    Hakyll.Core.Dependencies Hakyll.Core.File Hakyll.Core.Identifier
    Hakyll.Core.Identifier.Pattern Hakyll.Core.Item
    Hakyll.Core.Metadata Hakyll.Core.Routes Hakyll.Core.Rules
    Hakyll.Core.UnixFilter Hakyll.Core.Util.String Hakyll.Core.Writable
    Hakyll.Main Hakyll.Web.CompressCss Hakyll.Web.Feed Hakyll.Web.Html
    Hakyll.Web.Html.RelativizeUrls Hakyll.Web.Pandoc
    Hakyll.Web.Pandoc.Biblio Hakyll.Web.Pandoc.FileType Hakyll.Web.Tags
    Hakyll.Web.Paginate Hakyll.Web.Template Hakyll.Web.Template.Context
    Hakyll.Web.Template.Internal Hakyll.Web.Template.Internal.Element
    Hakyll.Web.Template.Internal.Trim Hakyll.Web.Template.List
hidden-modules: Data.List.Extended Data.Yaml.Extended Hakyll.Check
                Hakyll.Commands Hakyll.Core.Compiler.Internal
                Hakyll.Core.Compiler.Require Hakyll.Core.Item.SomeItem
                Hakyll.Core.Logger Hakyll.Core.Provider
                Hakyll.Core.Provider.Internal Hakyll.Core.Provider.Metadata
                Hakyll.Core.Provider.MetadataCache Hakyll.Core.Rules.Internal
                Hakyll.Core.Runtime Hakyll.Core.Store Hakyll.Core.Util.File
                Hakyll.Core.Util.Parser Hakyll.Web.Pandoc.Binary Paths_hakyll
                Hakyll.Preview.Poll Hakyll.Preview.Server
abi: fbfd97517ffcded4a74d427bf39e8438
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hakyll-4.9.2.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/hakyll-4.9.2.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/hakyll-4.9.2.0
hs-libraries: HShakyll-4.9.2.0-KCb9Tlj9EDQ1Ndzd854zVD
depends:
    base-4.9.0.0 binary-0.8.3.0
    blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP bytestring-0.10.8.1
    containers-0.5.7.1 cryptohash-0.11.9-6KWjXG2Y77tCLfbEj0PLeD
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr deepseq-1.4.2.0
    directory-1.2.6.2 filepath-1.4.1.0
    fsnotify-0.2.1-AbK6POsDNvc2W7OcESHkcO
    http-conduit-2.2.3-KvT3Ya3by0xHBleI7t1lhb
    http-types-0.9.1-58mzFhAgNAb9DH0XYXjd5P
    lrucache-1.2.0.0-FcRjavb3jD25yMz1yt0xu3
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
    optparse-applicative-0.13.0.0-IErSQpKP3j4oJy1jHSvi1
    pandoc-1.19.1-1GdTfOBgmNy6OW5eGvm2K6
    pandoc-citeproc-0.10.3-6HqkRuUPUk0D1uzYVGPYxc
    parsec-3.1.11-IYEP8Lv1S9x5FeUQxGPDBY process-1.4.2.0
    random-1.1-54KmMHXjttlERYcr1mvsAe
    regex-base-0.93.2-4lnOy3Rb1yfISFVEXVfJuH
    regex-tdfa-1.2.2-LZ7BXF6FmWOD2v5FByhfgx
    resourcet-1.1.9-J17FkGhZ2yV57Ehh8hruPC
    scientific-0.3.4.9-Ghl8M4Ey2fMI7e1yk2TuuH
    system-filepath-0.4.13.4-24DUGoIUqZu3MxGDhYLfCN
    tagsoup-0.14-Cyor6HaGaUK6jsf16bXCqB
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    time-locale-compat-0.1.1.1-HUIdYN9kpfnDYb4ETBn6RW
    unordered-containers-0.2.7.2-fKwgRekRaR5O5PqcoNK7l
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
    wai-3.2.1.1-1tyXra1bExD5E5dzTFMy2m
    wai-app-static-3.1.6.1-D3WwXNFbseJITVrBkAuXiu
    warp-3.2.9-7GWv5zPVIbw2Z87Xu6AzXn
    yaml-0.8.21.1-AB9cUezr1Bp3sqnRbgQ2D0
haddock-interfaces: /usr/share/doc/haskell-hakyll/html/hakyll.haddock
haddock-html: /usr/share/doc/haskell-hakyll/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hakyll-4.9.5.0-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hakyll.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hakyll
version: 4.9.5.0
id: hakyll-4.9.5.0-BRg2B3JFw2lCB0UD0GqysT
key: hakyll-4.9.5.0-BRg2B3JFw2lCB0UD0GqysT
license: BSD3
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
homepage: http://jaspervdj.be/hakyll
synopsis: A static website compiler library
description:
    Hakyll is a static website compiler library. It provides you with the tools to
    create a simple or advanced static website using a Haskell DSL and formats
    such as markdown or RST. You can find more information, including a tutorial,
    on the website:
    .
    * <http://jaspervdj.be/hakyll>
    .
    If you seek assistance, there'\''s:
    .
    * A google group: <http://groups.google.com/group/hakyll>
    .
    * An IRC channel, @#hakyll@ on freenode
    .
    Additionally, there'\''s the Haddock documentation in the different modules,
    meant as a reference.
category: Web
author: Jasper Van der Jeugt <m@jaspervdj.be>
exposed: True
exposed-modules:
    Hakyll Hakyll.Commands Hakyll.Core.Compiler
    Hakyll.Core.Configuration Hakyll.Core.Dependencies Hakyll.Core.File
    Hakyll.Core.Identifier Hakyll.Core.Identifier.Pattern
    Hakyll.Core.Item Hakyll.Core.Metadata Hakyll.Core.Routes
    Hakyll.Core.Rules Hakyll.Core.UnixFilter Hakyll.Core.Util.String
    Hakyll.Core.Writable Hakyll.Main Hakyll.Web.CompressCss
    Hakyll.Web.Feed Hakyll.Web.Html Hakyll.Web.Html.RelativizeUrls
    Hakyll.Web.Pandoc Hakyll.Web.Pandoc.Biblio
    Hakyll.Web.Pandoc.FileType Hakyll.Web.Redirect Hakyll.Web.Tags
    Hakyll.Web.Paginate Hakyll.Web.Template Hakyll.Web.Template.Context
    Hakyll.Web.Template.Internal Hakyll.Web.Template.Internal.Element
    Hakyll.Web.Template.Internal.Trim Hakyll.Web.Template.List
hidden-modules: Data.List.Extended Data.Yaml.Extended Hakyll.Check
                Hakyll.Core.Compiler.Internal Hakyll.Core.Compiler.Require
                Hakyll.Core.Item.SomeItem Hakyll.Core.Logger Hakyll.Core.Provider
                Hakyll.Core.Provider.Internal Hakyll.Core.Provider.Metadata
                Hakyll.Core.Provider.MetadataCache Hakyll.Core.Rules.Internal
                Hakyll.Core.Runtime Hakyll.Core.Store Hakyll.Core.Util.File
                Hakyll.Core.Util.Parser Hakyll.Web.Pandoc.Binary Paths_hakyll
                Hakyll.Preview.Poll Hakyll.Preview.Server
abi: 7fb4994e796b81dfc5bb955993c3e7d6
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hakyll-4.9.5.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/hakyll-4.9.5.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/hakyll-4.9.5.0
hs-libraries: HShakyll-4.9.5.0-BRg2B3JFw2lCB0UD0GqysT
depends:
    base-4.9.0.0 binary-0.8.3.0
    blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP bytestring-0.10.8.1
    containers-0.5.7.1 cryptohash-0.11.9-DHI6HEU0ngdHLXXk1TIe9A
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr deepseq-1.4.2.0
    directory-1.2.6.2 filepath-1.4.1.0
    fsnotify-0.2.1-AbK6POsDNvc2W7OcESHkcO
    http-conduit-2.2.3-15qfs2XpUkxHtyYvTq6e8Z
    http-types-0.9.1-86VKlfjfTunGvWNFdOLeV5
    lrucache-1.2.0.0-I5QCcQsxaJ820EG1Od5UTy
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
    optparse-applicative-0.13.0.0-IErSQpKP3j4oJy1jHSvi1
    pandoc-1.19.1-BLnfFG2ojgoCpv6pvDSs14
    pandoc-citeproc-0.10.3-8IPwL1euEKUHUUmOahnyAU
    parsec-3.1.11-IYEP8Lv1S9x5FeUQxGPDBY process-1.4.2.0
    random-1.1-54KmMHXjttlERYcr1mvsAe
    regex-base-0.93.2-4lnOy3Rb1yfISFVEXVfJuH
    regex-tdfa-1.2.2-LZ7BXF6FmWOD2v5FByhfgx
    resourcet-1.1.9-J17FkGhZ2yV57Ehh8hruPC
    scientific-0.3.4.9-1EMxAMphVKV1cR2UEyLvhJ
    system-filepath-0.4.13.4-24DUGoIUqZu3MxGDhYLfCN
    tagsoup-0.14-Cyor6HaGaUK6jsf16bXCqB
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    time-locale-compat-0.1.1.3-1j5dGjxxtiTDuAsO86iSk0
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
    wai-3.2.1.1-9mMHgVB1wYz4uCkr33AuWK
    wai-app-static-3.1.6.1-ETIWyX0ndVg2nHnsVnqWsR
    warp-3.2.9-4a6ooOXe4CeI3DiHXEQz1V
    yaml-0.8.21.1-AVEYDGyJx5gG3MACMHmcea
haddock-interfaces: /usr/share/doc/haskell-hakyll/html/hakyll.haddock
haddock-html: /usr/share/doc/haskell-hakyll/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
